//+------------------------------------------------------------------+
//|                                               Info Indicator.mq4 |
//|                        Copyright 2020, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2020, MetaQuotes Software Corp."
#property link      "https://www.mql5.com"
#property version   "1.00"
#property strict
#property indicator_separate_window
#property indicator_minimum 0
#property indicator_maximum 1


bool initFinished=false;
// adding a variable that will remember the initialization state.
// false - there was no initialization
// true - there was initialization

int period[]= {1,5,15,30,60,240,1440,10080,43200};
string periodString[]= {"M1","M5","M15","M30","H1","H4","D1","W1","MN1"};
string SignalNameString[]= {"MA20","MA50","MA100","BULLS","BEARS","MACD","ADX(14)","CCI(14)","AO"};

int scaleX=60, // horizontal interval at which the squares are created
           scaleY=30, // vertical interval
           offsetX=50, // horizontal indent of all squares
           offsetY=50, // vertical indent
           fontSize=30, // font size
           corner=0;

extern color SignalBuyColor=clrGreen,
             SignalSellColor=clrRed;
//noSignalBUYColor=WhiteSmoke, //Disabled for the moment
//textColor=Gold;           //Disabled for the moment

extern int MA_Period_1 = 20;
extern int MA_Period_2 = 50;
extern int MA_Period_3 = 100;
extern int Bulls_Period = 13;
extern int Bears_Period = 13;
extern int Fast_EMA = 12;
extern int Slow_EMA = 26;
extern int MACD_SMA = 9;
extern int ADX_Period = 14;
extern int CCI_Period = 14;

//--- indicator buffers
double Buffer1[];
double Buffer2[];
double Buffer3[];
double Buffer4[];
double Buffer5[];
double Buffer6[];
double Buffer7[];
double Buffer8[];
double Buffer9[];
double Buffer10[];
double Buffer11[];
double Buffer12[];

double myPoint; //initialized in OnInit


//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()


  {
   uint indynames_max=0;
   TextSetFont("Arial Black",8,0,0);
   int x;
   int y;
   for(int y=0; y<8; y++)
     {
      uint w,h;
      TextGetSize(SignalNameString[y],w,h);
      if(w>indynames_max)
         indynames_max=w;
     }
   int xm=indynames_max+offsetX;
   for(int x=0; x<9; x++)
      for(int y=0; y<8; y++)
        {
         ObjectCreate("Signal"+x+y,OBJ_LABEL,WindowFind("Multi Info Panel"),0,0,0,0);
         ObjectSet("Signal"+x+y,OBJPROP_CORNER,corner);
         // change the corner
         ObjectSet("Signal"+x+y,OBJPROP_XDISTANCE,x*scaleX+xm);
         ObjectSet("Signal"+x+y,OBJPROP_YDISTANCE,y*scaleY+offsetY);
         ObjectSetText("Signal"+x+y,"BUY",10,"Arial Black",SignalBuyColor);
        }



// name of timeframes
   for(x=0; x<9; x++)
     {
      ObjectCreate("textPeriod"+x,OBJ_LABEL,WindowFind("Multi Info Panel"),0,0,0,0);
      //ObjectSet("textPeriod"+x,OBJPROP_CORNER,corner);
      // changing the corner
      ObjectSet("textPeriod"+x,OBJPROP_XDISTANCE,x*scaleX+xm+(scaleX/2));
      ObjectSet("textPeriod"+x,OBJPROP_YDISTANCE,offsetY+scaleY/8);
      ObjectSetText("textPeriod"+x,periodString[x],8,"Arial Black",Gold);
      ObjectSetDouble(ChartID(),"textPeriod"+x,OBJPROP_ANGLE,90);
      ObjectSetInteger(ChartID(),"textPeriod"+x,OBJPROP_ANCHOR,ANCHOR_LEFT);
     }

// names of indicators
   for(y=0; y<8; y++)
     {
      ObjectCreate("textSignal"+y,OBJ_LABEL,WindowFind("Multi Info Panel"),0,0,0,0);
      //ObjectSet("textSignal"+y,OBJPROP_CORNER,corner);
      // change the corner
      ObjectSet("textSignal"+y,OBJPROP_XDISTANCE,xm);
      ObjectSet("textSignal"+y,OBJPROP_YDISTANCE,y*scaleY+offsetY+scaleY/2);
      ObjectSetText("textSignal"+y,SignalNameString[y],8,"Arial Black",Gold);
      ObjectSetInteger(ChartID(),"textSignal"+y,OBJPROP_ANCHOR,ANCHOR_RIGHT_UPPER);
     }




//initialize myPoint
   myPoint = Point();
   if(Digits() == 5 || Digits() == 3)
     {
      myPoint *= 10;
     }

   return(INIT_SUCCEEDED);
  }

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime& time[],
                const double& CLOSE[],
                const double& high[],
                const double& low[],
                const double& close[],
                const long& tick_volume[],
                const long& volume[],
                const int& spread[])
  {
   int limit = rates_total - prev_calculated;

   ArraySetAsSeries(Buffer1, true);
   ArraySetAsSeries(Buffer2, true);
   ArraySetAsSeries(Buffer3, true);
   ArraySetAsSeries(Buffer4, true);
   ArraySetAsSeries(Buffer5, true);
   ArraySetAsSeries(Buffer6, true);
   ArraySetAsSeries(Buffer7, true);
   ArraySetAsSeries(Buffer8, true);
   ArraySetAsSeries(Buffer9, true);
   ArraySetAsSeries(Buffer10, true);
   ArraySetAsSeries(Buffer11, true);
   ArraySetAsSeries(Buffer12, true);

   if(prev_calculated < 1)
     {
      ArrayInitialize(Buffer1, 0);
      ArrayInitialize(Buffer2, 0);
      ArrayInitialize(Buffer3, 0);
      ArrayInitialize(Buffer4, 0);
      ArrayInitialize(Buffer5, 0);
      ArrayInitialize(Buffer6, 0);
      ArrayInitialize(Buffer7, 0);
      ArrayInitialize(Buffer8, 0);
      ArrayInitialize(Buffer9, 0);
      ArrayInitialize(Buffer10, 0);
      ArrayInitialize(Buffer11, 0);
      ArrayInitialize(Buffer12, 0);
     }
   else
      limit++;

//--- main loop
   for(int i = limit-1; i >= 0; i--)
     {
      if(i >= MathMin(5000-1, rates_total-1-50))
         continue; //omit some old rates to prevent "Array out of range"

      //-

      //Loop to timeframes starts here
      for(int x=0; x<9; x++)
        {

         //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

         //Indicator Buffer 1

         if(iMA(NULL, period[x], MA_Period_1, 0, MODE_SMA, PRICE_CLOSE, 1+i) <= iMA(NULL, period[x], MA_Period_1, 0, MODE_SMA, PRICE_CLOSE, i) //Moving Average <= Moving Average
           )

            ObjectSetText("Signal"+x+"0","BUY",10,"Arial Black",SignalBuyColor);
         else
           {
            ObjectSetText("Signal"+x+"0","SELL",10,"Arial Black",SignalSellColor);
           }

         //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

         //Indicator Buffer 2

         if(iMA(NULL, period[x], MA_Period_2, 0, MODE_SMA, PRICE_CLOSE, 1+i) <= iMA(NULL, period[x], MA_Period_2, 0, MODE_SMA, PRICE_CLOSE, i) //Moving Average <= Moving Average
           )

            ObjectSetText("Signal"+x+"1","BUY",10,"Arial Black",SignalBuyColor);
         else
           {
            ObjectSetText("Signal"+x+"1","SELL",10,"Arial Black",SignalSellColor);
           }

         //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

         //Indicator Buffer 3

         if(iMA(NULL, period[x], MA_Period_3, 0, MODE_SMA, PRICE_CLOSE, 1+i) <= iMA(NULL, period[x], MA_Period_3, 0, MODE_SMA, PRICE_CLOSE, i) //Moving Average <= Moving Average
           )


            ObjectSetText("Signal"+x+"2","BUY",10,"Arial Black",SignalBuyColor);
         else
           {
            ObjectSetText("Signal"+x+"2","SELL",10,"Arial Black",SignalSellColor);
           }

         //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

         //Indicator Buffer 4

         if(iBullsPower(NULL, period[x], Bulls_Period, PRICE_CLOSE, 1+i) <= iBullsPower(NULL, period[x], Bulls_Period, PRICE_CLOSE, i) //Bulls Power <= Bulls Power
           )
            ObjectSetText("Signal"+x+"3","BUY",10,"Arial Black",SignalBuyColor);
         else
           {
            ObjectSetText("Signal"+x+"3","SELL",10,"Arial Black",SignalSellColor);
           }

         //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

         //Indicator Buffer 5

         if(iBearsPower(NULL, period[x], Bears_Period, PRICE_CLOSE, 1+i) <= iBearsPower(NULL, period[x], Bears_Period, PRICE_CLOSE, i) //Bears Power <= Bears Power
           )
            ObjectSetText("Signal"+x+"4","BUY",10,"Arial Black",SignalBuyColor);
         else
           {
            ObjectSetText("Signal"+x+"4","SELL",10,"Arial Black",SignalSellColor);
           }

         //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

         //Indicator Buffer 6

         if(iMACD(NULL, period[x], Fast_EMA, Slow_EMA, MACD_SMA, PRICE_CLOSE, MODE_MAIN, 1+i) <= iMACD(NULL, period[x], Fast_EMA, Slow_EMA, MACD_SMA, PRICE_CLOSE, MODE_MAIN, i) //MACD <= MACD
           )

            ObjectSetText("Signal"+x+"5","BUY",10,"Arial Black",SignalBuyColor);
         else
           {
            ObjectSetText("Signal"+x+"5","SELL",10,"Arial Black",SignalSellColor);
           }

         //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

         //Indicator Buffer 7

         if(iADX(NULL, period[x], ADX_Period, PRICE_CLOSE, MODE_MAIN, 1+i) <= iADX(NULL, period[x], ADX_Period, PRICE_CLOSE, MODE_MAIN, i) //Average Directional Movement Index <= Average Directional Movement Index
           )

            ObjectSetText("Signal"+x+"6","BUY",10,"Arial Black",SignalBuyColor);
         else
           {
            ObjectSetText("Signal"+x+"6","SELL",10,"Arial Black",SignalSellColor);
           }

         //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

         //Indicator Buffer 8
         if(iCCI(NULL, period[x], CCI_Period, PRICE_TYPICAL, 1+i) <= iCCI(NULL, period[x], CCI_Period, PRICE_TYPICAL, i) //Commodity Channel Index <= Commodity Channel Index
           )

            ObjectSetText("Signal"+x+"7","BUY",10,"Arial Black",SignalBuyColor);
         else
           {
            ObjectSetText("Signal"+x+"7","SELL",10,"Arial Black",SignalSellColor);
           }




        }

        {
         if(initFinished==false)
           {
            IndicatorShortName("Multi Info Panel");

            int windowIndex=WindowFind("Multi Info Panel");

            if(windowIndex<0)
              {
               // if the subwindow number is -1, there is an error
               Print("Can\'t find window");
               return(0);
              }


            WindowRedraw();
            // redraw the window to see the line

            initFinished=true;
            // drawing is finished
           }

         return(0);
        }



     }//main loop ends here

   return(0);

  }//OnCalculate ends here
//+-----------------------------------------------------------
//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
   ObjectsDeleteAll();
// deleting all objects

   return(0);
  }
